=======
Credits
=======

The pvl library was originally developed by Trevor Olson.

Authors
-------

* Trevor Olson <trevor@heytrevor.com> (Original Author and former development lead)
* Sarah Braden <braden.sarah@gmail.com>
* Michael Aye <kmichael.aye@gmail.com>
* Austin Godber <godber@uberhip.com>
* Perry Vargas <perrybvargas@gmail.com>
* `Benoit Seignovert <https://github.com/seignovert>`_
* `Ross Beyer <https://github.com/rbeyer>`_


Acknowledgements
----------------

Thanks to Michael Aye, Andrew Annex, and Chase Million for valuable discussions during the
lead-up to the 1.0.0 release.